@@ -746,7 +746,7 @@ realvar dataset::eval_exp(ST::string  expression, bool clearerrors)
           {
 #if defined(JAVA_OUTPUT_WINDOW)
           realvar h(nrobs);
-          register unsigned i;
+          unsigned i;
           realvar::iterator it = h.begin();
 
           jmethodID javauniform = adminb_p->Java->GetMethodID(
@@ -772,7 +772,7 @@ realvar dataset::eval_exp(ST::string  expression, bool clearerrors)
           {
 #if defined(JAVA_OUTPUT_WINDOW)
           realvar h(nrobs);
-          register unsigned i;
+          unsigned i;
           realvar::iterator it = h.begin();
 
           jmethodID javanormal = adminb_p->Java->GetMethodID(
@@ -813,7 +813,7 @@ realvar dataset::eval_exp(ST::string  expression, bool clearerrors)
    		  valuevek = eval_exp(arglist[0],false);
 #if defined(JAVA_OUTPUT_WINDOW)
           realvar h(nrobs);
-          register unsigned i;
+          unsigned i;
           realvar::iterator it = h.begin();
 
           jmethodID javaexponential = adminb_p->Java->GetMethodID(
@@ -853,7 +853,7 @@ realvar dataset::eval_exp(ST::string  expression, bool clearerrors)
    		  valuevek = eval_exp(arglist[0],false);
 #if defined(JAVA_OUTPUT_WINDOW)
           realvar h(nrobs);
-          register unsigned i;
+          unsigned i;
           realvar::iterator it = h.begin();
 
           jmethodID javapoisson = adminb_p->Java->GetMethodID(
@@ -895,7 +895,7 @@ realvar dataset::eval_exp(ST::string  expression, bool clearerrors)
 		  valuevek2 = eval_exp(arglist[1],false);
 #if defined(JAVA_OUTPUT_WINDOW)
           realvar h(nrobs);
-          register unsigned i;
+          unsigned i;
           realvar::iterator it = h.begin();
 
           jmethodID javaweibull = adminb_p->Java->GetMethodID(
@@ -936,7 +936,7 @@ realvar dataset::eval_exp(ST::string  expression, bool clearerrors)
           valuevek = eval_exp(arglist[0],false);
 #if defined(JAVA_OUTPUT_WINDOW)
           realvar h(nrobs);
-          register unsigned i;
+          unsigned i;
           realvar::iterator it = h.begin();
 
           jmethodID javabernoulli = adminb_p->Java->GetMethodID(
@@ -977,7 +977,7 @@ realvar dataset::eval_exp(ST::string  expression, bool clearerrors)
 		  valuevek2 = eval_exp(arglist[1],false);
 #if defined(JAVA_OUTPUT_WINDOW)
           realvar h(nrobs);
-          register unsigned i;
+          unsigned i;
           realvar::iterator it = h.begin();
 
           jmethodID javabinomial = adminb_p->Java->GetMethodID(
@@ -1020,7 +1020,7 @@ realvar dataset::eval_exp(ST::string  expression, bool clearerrors)
 		  valuevek2 = eval_exp(arglist[1],false);
 #if defined(JAVA_OUTPUT_WINDOW)
           realvar h(nrobs);
-          register unsigned i;
+          unsigned i;
           realvar::iterator it = h.begin();
 
           jmethodID javagamma = adminb_p->Java->GetMethodID(
@@ -1236,6 +1236,7 @@ unsigned dataset::replace(const ST::string & name,const ST::string & e,const ST:
 	 vbool = eval_exp(boole);
 
   if (errormessages.empty())
+    {
 	 if (boole.length() != 0)
 		{
         unsigned i;
@@ -1255,6 +1256,7 @@ unsigned dataset::replace(const ST::string & name,const ST::string & e,const ST:
        *varit = vneu;
        changed = nrobs;
        }
+     }
 
   return changed;
   }
@@ -1513,7 +1515,7 @@ void dataset::makematrix(ST::string & name, datamatrix & d, ST::string boole)
 
 void dataset::reverseorder(void)
   {
-  register unsigned i;
+  unsigned i;
   vector<int> help = datarep.index;
   vector<int>::iterator hit = help.end()-1;
   vector<int>::iterator it = datarep.index.begin();
@@ -1538,13 +1540,15 @@ void dataset::marketing(vector<ST::string> & names, ST::string & defs, int & lak
 
   int nrout=0;
   int nrwoche=0;
+  int found=0;
 
   unsigned i;
   for(i=0;i<names.size()-2;i++)    //durchluft die Variablen outlet, wochenin
     {
     list<ST::string>namen;
     namen.push_back(names[i]);
-    int found = datarep.findvar(names[i],stit,varitwo);  //damit man varit bekommt und spter Werte auslesen kann
+    found = datarep.findvar(names[i],stit,varitwo);  //damit man varit bekommt und spter Werte auslesen kann
+
     sort(namen,0,nrobs-1);   //sortiert nach Variable "i"
     unsigned k = 0;      //Anzahl der Beobachtungen der einzelnen Variablen feststellen
     int zaehler = 0;
@@ -1575,7 +1579,7 @@ void dataset::marketing(vector<ST::string> & names, ST::string & defs, int & lak
   sort(namen,0,nrobs-1);   // endgltiges Sortieren; Reihenfolge: markenin, outlet, wochenin, preis
   realvar wert(nrobs,NA);      //erzeugt neue Variable, die spter den minimalen Preis pro Marke enthlt
 
-  int found = datarep.findvar(names[3],stit,varitp);    //Zeiger auf "preis"
+  found = datarep.findvar(names[3],stit,varitp);    //Zeiger auf "preis"
   found = datarep.findvar(names[1],stit,varitwo);       //Zeiger auf "wochenin"
   found = datarep.findvar(names[2],stit,varitm);        //Zeiger auf "markenin"
 
